==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/InfrastructureSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface InfrastructureSpecFluent<A extends io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCloudConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapFileReference getCloudConfig();
  public io.fabric8.openshift.api.model.ConfigMapFileReference buildCloudConfig();
  public A withCloudConfig(io.fabric8.openshift.api.model.ConfigMapFileReference cloudConfig);
  public java.lang.Boolean hasCloudConfig();
  public A withNewCloudConfig(java.lang.String key,java.lang.String name);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item);
  
  /**
   * This method has been deprecated, please use method buildPlatformSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformSpec getPlatformSpec();
  public io.fabric8.openshift.api.model.PlatformSpec buildPlatformSpec();
  public A withPlatformSpec(io.fabric8.openshift.api.model.PlatformSpec platformSpec);
  public java.lang.Boolean hasPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item);
  public interface CloudConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapFileReferenceFluent<io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>>{
    public N and();
    public N endCloudConfig();
    
  }
  public interface PlatformSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PlatformSpecFluent<io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>>{
    public N and();
    public N endPlatformSpec();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/InfrastructureSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface InfrastructureSpecFluent<A extends io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCloudConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapFileReference getCloudConfig();
  public io.fabric8.openshift.api.model.ConfigMapFileReference buildCloudConfig();
  public A withCloudConfig(io.fabric8.openshift.api.model.ConfigMapFileReference cloudConfig);
  public java.lang.Boolean hasCloudConfig();
  public A withNewCloudConfig(java.lang.String key,java.lang.String name);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfig();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item);
  
  /**
   * This method has been deprecated, please use method buildPlatformSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformSpec getPlatformSpec();
  public io.fabric8.openshift.api.model.PlatformSpec buildPlatformSpec();
  public A withPlatformSpec(io.fabric8.openshift.api.model.PlatformSpec platformSpec);
  public java.lang.Boolean hasPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item);
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpec();
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CloudConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapFileReferenceFluent<io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>>{
    public N and();
    public N endCloudConfig();
    
  }
  public interface PlatformSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PlatformSpecFluent<io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>>{
    public N and();
    public N endPlatformSpec();
    
  }
  
}
